define((function () { 'use strict';

	function yar() {
		console.log('yar?');
	}

	yar();

}));
